# APISKEEK

APISKEEK is a custom dashboard for FastAPI endpoints. It displays each API’s URL along with the total requests made, the count of successful responses, and failed requests.

## Installation

```bash
pip install apiseek
